@@ -11,11 +11,15 @@ class LcOption:
                         'X-LC-Key': kwargs.get('app_key', os.getenv('LC_KEY')),
                         'Content-Type': 'application/json'}
 
-    def get(self, id, **kwargs):
-        url = f'{BASE_URL}/{id}'
+    def get(self, in_id, **kwargs):
+        url = f'{BASE_URL}/{in_id}'
         res = requests.get(url, headers=self.headers, **kwargs)
         return self.process_response(res)
 
+    def get_value(self, in_id, **kwargs):
+        res = self.get(in_id, **kwargs)
+        return res['value']
+
     def post(self, id, **kwargs):
         url = f'{BASE_URL}/{id}'
         data = kwargs.get('data', {})
